<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/mainmenu.cpp" line="57"/>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="61"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="65"/>
        <source>Credits</source>
        <translation>Zásluhy</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="69"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="77"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>At least OpenGL ES 2.0 is required!</source>
        <translation type="vanished">Je vyžadováno alespoň OpenGL ES 2.0!</translation>
    </message>
    <message>
        <source>Cannot start Dust Racing 2D</source>
        <translation type="vanished">Nelze spustit Dust Racing 2D</translation>
    </message>
    <message>
        <source>At least OpenGL 3.0 is required!</source>
        <translation type="vanished">Je vyžadováno alespoň OpenGL 3.0!</translation>
    </message>
    <message>
        <source>At least OpenGL 2.1 is required!</source>
        <translation type="vanished">Je vyžadováno alespoň OpenGL 2.1!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="347"/>
        <source>The Time Trial has ended!</source>
        <translation>Časová zkouška!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="351"/>
        <source>The winner has finished!</source>
        <translation>Vítěz dokončil!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="69"/>
        <source>New lap record!</source>
        <translation>Nový rekord kola!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="76"/>
        <source>New race record!</source>
        <translation>Nový rekord závodu!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="376"/>
        <source>Pit stop!</source>
        <translation>Díra!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="569"/>
        <source>A new best pos!</source>
        <translation>Nové nejlepší umístění!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="579"/>
        <source>A new track unlocked!</source>
        <translation>Odemknuta nová trať!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="583"/>
        <source>Better luck next time..</source>
        <translation>Příště víc štěstí..</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="626"/>
        <source>You must stay on track!</source>
        <translation>Musíte zůstat na trati!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="630"/>
        <source>Watch your tires!</source>
        <translation>Kontrolujte pláště!</translation>
    </message>
    <message>
        <location filename="../startlights.cpp" line="135"/>
        <source>GO!!!</source>
        <translation>Jeďte!</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="52"/>
        <source>---</source>
        <translation>---</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="53"/>
        <source>1st</source>
        <translation>1.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="54"/>
        <source>2nd</source>
        <translation>2.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="55"/>
        <source>3rd</source>
        <translation>3.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="56"/>
        <source>4th</source>
        <translation>4.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="57"/>
        <source>5th</source>
        <translation>5.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="58"/>
        <source>6th</source>
        <translation>6.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="59"/>
        <source>7th</source>
        <translation>7.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="60"/>
        <source>8th</source>
        <translation>8.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="61"/>
        <source>9th</source>
        <translation>9.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="62"/>
        <source>10th</source>
        <translation>10.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="63"/>
        <source>11th</source>
        <translation>11.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="64"/>
        <source>12th</source>
        <translation>12.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="185"/>
        <source> LAP:</source>
        <translation> KOLO:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="202"/>
        <source> POS:</source>
        <extracomment>Position/rank</extracomment>
        <translation> UMÍS:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAP</source>
        <translation>KOLO</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAPS</source>
        <translation>KOLA</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="247"/>
        <source> KM/H</source>
        <translation> KM/H</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="260"/>
        <source>LAP:</source>
        <translation>KOLO:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="306"/>
        <source>L:</source>
        <extracomment>Last lap time</extracomment>
        <translation>K:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="326"/>
        <source>R:</source>
        <extracomment>Lap record time</extracomment>
        <translation>R:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="347"/>
        <source>TOT:</source>
        <extracomment>Total race time</extracomment>
        <translation>CELKEM:</translation>
    </message>
    <message>
        <location filename="../menu/help.cpp" line="31"/>
        <source>GAME GOAL

You are racing against eleven
computer players.

Your best position will be
the next start position.

Finish in TOP-6 to unlock
a new race track!

CONTROLS FOR PLAYER 1

Turn left  : Left
Turn right : Right
Accelerate : Up / RIGHT SHIFT
Brake      : Down / RIGHT CTRL

CONTROLS FOR PLAYER 2

Turn left  : A
Turn right : D
Accelerate : W / LEFT SHIFT
Brake      : S / LEFT CTRL

Quit       : ESC/Q
Pause      : P</source>
        <translation>CÍL HRY

Závodíte s jedenácti
počítačovými hráči.

Vaše nejlepší umístění bude
další startovní pozicí.

Skončete mezi nejlepšími šesti pro
odemknutí nové závodní tratě!

OVLÁDÁNÍ HRÁČE 1

Zabočit doleva: šipka vlevo
Zabočit doprava: šipka vpravo
Zrychlit: šipka nahoru / pravý SHIFT
Brzdit: šipka dolů / pravý CTRL

OVLÁDÁNÍ HRÁČE 2

Zabočit doleva : A
Zabočit doprava: D
Zrychlit: W / levý SHIFT
Brzdit: S / levý CTRL

Ukončit: ESC/Q
Pozastavit: P</translation>
    </message>
    <message>
        <source>PROGRAMMING BY

* Jussi Lind

GRAPHICS BY

* Jussi Lind
* Ville Makiranta
* FindIcons.com

RACE TRACKS BY

* Jussi Lind

FONT

* Ubuntu Monospace

PATCHES

* Markus Rinne

SPECIAL THANKS

* Tommi Martela</source>
        <translation type="obsolete">PROGRAMOVÁNÍ

* Jussi Lind

OBRAZOVÁ STRÁNKA

* Jussi Lind
* Ville Makiranta
* FindIcons.com

ZÁVODNÍ TRATĚ

* Jussi Lind

PÍSMO

* Ubuntu Monospace

ZÁPLATY

* Markus Rinne

ZVLÁŠTNÍ PODĚKOVÁNÍ

* Tommi Martela</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="78"/>
        <source>Reset best positions?</source>
        <translation>Vynulovat nejlepší umístění?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="89"/>
        <source>Reset record times?</source>
        <translation>Vynulovat rekordní časy?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="101"/>
        <source>Reset unlocked tracks?</source>
        <translation>Vynulovat odemknuté tratě!</translation>
    </message>
    <message>
        <source>Difficulty &gt;</source>
        <translation type="vanished">Obtížnost &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="204"/>
        <source>Sounds &gt;</source>
        <translation>Zvuk &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="208"/>
        <source>GFX &gt;</source>
        <translation>Obraz &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="212"/>
        <source>Controls &gt;</source>
        <translation>Ovládání &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="216"/>
        <source>Reset &gt;</source>
        <translation>Vynulování &gt;</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="42"/>
        <source>Easy</source>
        <translation>Lehká</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="52"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="62"/>
        <source>Hard</source>
        <translation>Těžký</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="374"/>
        <source>VSync &gt;</source>
        <translation>Svislá synchronizace &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="393"/>
        <location filename="../menu/vsyncmenu.cpp" line="99"/>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="405"/>
        <location filename="../menu/vsyncmenu.cpp" line="103"/>
        <source>On</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="435"/>
        <source>Reset record times</source>
        <translation>Vynulovat rekordní časy</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="439"/>
        <source>Reset best positions</source>
        <translation>Vynulovat nejlepší umístění</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="443"/>
        <source>Reset unlocked tracks</source>
        <translation>Vynulovat odemknuté tratě</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="358"/>
        <source>Full screen resolution &gt;</source>
        <translation>Rozlišení v režimu na celou obrazovku &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="362"/>
        <source>Windowed resolution &gt;</source>
        <translation>Rozlišení v okenním režimu &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="370"/>
        <source>Split type &gt;</source>
        <translation>Typ rozdělení &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="200"/>
        <source>Game mode &gt;</source>
        <translation>Herní režim &gt; </translation>
    </message>
    <message>
        <source>Lap Count &gt;</source>
        <translation type="vanished">Počet kol &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="366"/>
        <source>FPS &gt;</source>
        <translation type="unfinished">Snímků za sekundu &gt;</translation>
    </message>
    <message>
        <source>Key configuration &gt;</source>
        <translation type="obsolete">Nastavení kláves &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="277"/>
        <source>Two player race</source>
        <translation>Závod se dvěma závodníky</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="286"/>
        <source>One player race</source>
        <translation>Závod s jedním závodníkem</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="295"/>
        <source>Time Trial</source>
        <translation>Časová zkouška</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="304"/>
        <source>Duel</source>
        <translation>Duel</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="328"/>
        <source>Vertical</source>
        <translation>Svislé</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="337"/>
        <source>Horizontal</source>
        <translation>Vodorovné</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="236"/>
        <source>30 fps</source>
        <translation type="unfinished">30 fps</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="246"/>
        <source>60 fps</source>
        <translation type="unfinished">60 fps</translation>
    </message>
    <message>
        <source>  Laps: </source>
        <translation type="obsolete">  Kol: </translation>
    </message>
    <message>
        <source>Length: </source>
        <translation type="obsolete">Délka: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="266"/>
        <source>       Laps: </source>
        <translation>       Kol: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="273"/>
        <source>     Length: </source>
        <translation>       Délka: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="311"/>
        <source>Finish previous track in TOP-6 to unlock!</source>
        <extracomment>Try to keep the translation as short as possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="316"/>
        <source>Unlock it in one/two player race!</source>
        <extracomment>&quot;it&quot; = a locked track. Try to keep the translation as short as possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> m</source>
        <translation type="vanished"> m</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="280"/>
        <source> Lap Record: </source>
        <translation> Rekord kola: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="287"/>
        <source>Race Record: </source>
        <translation>Rekord závodu: </translation>
    </message>
    <message>
        <source>Record: </source>
        <translation type="obsolete">Rekord: </translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="49"/>
        <source>Press a key..</source>
        <translation>Stiskněte klávesu...</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="89"/>
        <source>Player One Accelerate</source>
        <translation>Závodník 1 zrychluje</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="98"/>
        <source>Player One Brake</source>
        <translation>Závodník 1 brzdí</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="107"/>
        <source>Player One Turn Left</source>
        <translation>Závodník 1 zahýbá doleva</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="116"/>
        <source>Player One Turn Right</source>
        <translation>Závodník 1 zahýbá doprava</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="138"/>
        <source>Player Two Accelerate</source>
        <translation>Závodník 2 zrychluje</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="147"/>
        <source>Player Two Brake</source>
        <translation>Závodník 2 brzdí</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="156"/>
        <source>Player Two Turn Left</source>
        <translation>Závodník 2 zahýbá doleva</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
        <source>Player Two Turn Right</source>
        <translation>Závodník 2 zahýbá doprava</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="31"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="32"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>PROGRAMMING BY</source>
        <translation type="vanished">PROGRAMOVÁNÍ</translation>
    </message>
    <message>
        <source>GRAPHICS BY</source>
        <translation type="vanished">OBRAZOVÁ STRÁNKA</translation>
    </message>
    <message>
        <source>RACE TRACKS BY</source>
        <translation type="vanished">ZÁVODNÍ TRATĚ</translation>
    </message>
    <message>
        <source>CONTRIBUTORS</source>
        <translation type="vanished">PŘISPĚVATELÉ</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="40"/>
        <source>PROGRAMMING</source>
        <translation>PROGRAMOVÁNÍ</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="42"/>
        <source>GRAPHICS</source>
        <translation>OBRAZOVÁ STRÁNKA</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="44"/>
        <source>LEVEL DESIGN</source>
        <translation>VNĚJŠÍ ÚPRAVA ÚROVNÍ</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="46"/>
        <source>TRANSLATIONS</source>
        <translation>PŘEKLAD</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="48"/>
        <source>PATCHES</source>
        <translation>ZÁPLATY</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="50"/>
        <source>SPECIAL THANKS</source>
        <translation>ZVLÁŠTNÍ PODĚKOVÁNÍ</translation>
    </message>
    <message>
        <location filename="../menu/resolutionmenu.cpp" line="115"/>
        <source>Restart to change the resolution.</source>
        <translation>Pro změnu rozlišení spusťte znovu.</translation>
    </message>
    <message>
        <source>Native resolution</source>
        <translation type="vanished">Přirozené rozlišení</translation>
    </message>
    <message>
        <location filename="../menu/vsyncmenu.cpp" line="75"/>
        <source>Restart to change VSync setting.</source>
        <translation>Pro změnu nastavení svislé synchronizace spusťte znovu.</translation>
    </message>
    <message>
        <location filename="../menu/lapcountmenu.cpp" line="84"/>
        <source>Choose lap count</source>
        <translation>Vyberte počet kol</translation>
    </message>
</context>
</TS>
